import { trigger, state, style, transition, group, animate } from '@angular/animations';

const ColorTransitionAnimation = trigger('colorTransition', [
    state('color1', style({
        'background': "{{ color1 }}",
    }), {
        params: {
            color1: '#000',
        }
    }),
    state('color2', style({
        'background': "{{ color2 }}",
    }), {
        params: {
            color2: '#444',
        }
    }),
    transition('color1 => color2', [
        group([
            animate('{{ duration }} ease-in-out', style({
                'background': "{{ color2 }}"
            })),
        ])
    ], {
        params: {
            color1: '#000',
            color2: '#444',
            duration: '1s',
        }
    }),
    transition('color2 => color1', [
        group([
            animate('{{ duration }} ease-in-out', style({
                'background': "{{ color1 }}"
            })),
        ])
    ], {
        params: {
            color1: '#000',
            color2: '#444',
            duration: '1s',
        }
    }),
]);

const FadeInOutAnimation = trigger('fadeInOut', [
    state('in', style({
        'opacity': '1',
    })),
    state('out', style({
        'opacity': '0',
    })),
    transition('in => out', [
        group([
            animate('600ms ease-in-out', style({
                'opacity': '0'
            })),
        ])
    ]),
    transition('out => in', [
        group([
            animate('600ms ease-in-out', style({
                'opacity': '1'
            })),
        ])
    ]),
]);

const SlideUpDownAnimation = trigger('slideUpDown', [
    state('down', style({
        'height': '*',
    })),
    state('up', style({
        'height': '0px',
    })),
    transition('down => up', [
        group([
            animate('300ms ease-in-out', style({
                'height': '0px'
            })),
        ])
    ]),
    transition('up => down', [
        group([
            animate('300ms ease-in-out', style({
                'height': '*'
            })),
        ])
    ]),
]);

/**
 * Generated bundle index. Do not edit.
 */

export { ColorTransitionAnimation, FadeInOutAnimation, SlideUpDownAnimation };
//# sourceMappingURL=mintplayer-ng-animations.js.map
